@@ -1,6 +1,7 @@
 from torch.utils.data import Dataset
-from skimage import io
 from PIL import Image
+import mplfinance as mf
+import numpy as np
 import torch
 import os
 import pandas as pd
@@ -42,7 +43,7 @@ class NetradeDataLoader(Dataset):
     chart_dirs = os.path.join(self.chart_dir, self.data_frame.iloc[idx, 2], self.data_frame.iloc[idx, 0])
 
     # read chart pattern image
-    chart_image = Image.fromarray(io.imread(chart_dirs))
+    chart_image = Image.fromarray(Image.open(chart_dirs))
 
     # convert chart image from others to RGB
     chart_image = chart_image.convert("RGB")
@@ -51,7 +52,7 @@ class NetradeDataLoader(Dataset):
     candle_dirs = os.path.join(self.candle_dir, self.data_frame.iloc[idx, 2], self.data_frame.iloc[idx, 1])
 
     # read candle pattern image
-    candle_image = Image.fromarray(io.imread(candle_dirs))
+    candle_image = Image.fromarray(Image.open(candle_dirs))
     
     # convert image channel from others to rgb
     candle_image = candle_image.convert("RGB")
@@ -68,6 +69,9 @@ class NetradeDataLoader(Dataset):
 
     return chart_image, candle_image, labels
 
+# Data preprocessing section
+# The code below do the preprocesing needs such as create data frame for training needs, shuffling and etc
+
 class DataPreprocessing:
   """
   This class used for data pre-processing and manipulating needs
@@ -78,7 +82,7 @@ class DataPreprocessing:
     self.chart_path = chart_path
     self.candle_path = candle_path
 
-  def create_frame(self):
+  def create_frame(self, shuffle : bool = False):
     """Generate pandas data frame for use in netrade data loader
 
     Args: 
@@ -110,6 +114,59 @@ class DataPreprocessing:
           result.append(context)
     
     frame = pd.DataFrame(result)
-    frame = frame.sample(frac=1)
 
-    return frame
\ No newline at end of file
+    # shuffle data if needed
+    if shuffle:
+      frame = frame.sample(frac=1)
+
+    return frame
+
+# data creation section
+# This section below shows the code base for data creation needs
+# such as create chart pattern and candle stick pattern image
+
+class DataCreation:
+  """
+  This class used for create data needs
+  """
+  def create_image(self, data : list = []):
+    """Create candle stick or chart pattern image and return it as PIL Image class.
+
+    Args:
+        data : pandas data frame -> list historycal data in pandas data frame format from yfinance or other
+
+    Returns:
+        image : PIL Image -> PIL image class
+    """
+
+    # make candlestick style just as the same with trading view color
+    mc = mf.make_marketcolors(up='#26A69A', edge='inherit', down='#EF5350', wick={"up" : '#26A69A', 'down': '#EF5350'})
+
+    # configuring figure style
+    s  = mf.make_mpf_style(gridstyle="", marketcolors=mc, edgecolor="#ffffff")
+
+    # create figure
+    fig = mf.figure(style=s)
+    ax = fig.add_subplot(1, 1, 1)
+
+    # remove x and y label
+    ax.axis(False)
+
+    # create candle stick
+    mf.plot(data,ax=ax,type="candle")
+
+    # draw candle stick into canvas
+    fig.canvas.draw()
+
+    # grab the pixel buffer and dump it into a numpy array
+    candle_arr = np.array(fig.canvas.renderer.buffer_rgba())
+
+    # convert numpy array to PIL image
+    img = Image.fromarray(candle_arr).convert("RGB")
+
+    return img
+
+if __name__ != "__main__":
+
+  # initiate data creation helper
+  data_creation = DataCreation()
\ No newline at end of file
